# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cdn/v1/origin_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.cdn.v1 import origin_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2
from yandex.cloud.cdn.v1 import origin_group_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/cdn/v1/origin_group_service.proto',
  package='yandex.cloud.cdn.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.yandex/cloud/cdn/v1/origin_group_service.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/cdn/v1/origin.proto\x1a&yandex/cloud/cdn/v1/origin_group.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"Y\n\x15GetOriginGroupRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\x0forigin_group_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"x\n\x17ListOriginGroupsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"l\n\x18ListOriginGroupsResponse\x12\x37\n\rorigin_groups\x18\x01 \x03(\x0b\x32 .yandex.cloud.cdn.v1.OriginGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xab\x01\n\x18\x43reateOriginGroupRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04name\x18\x02 \x01(\t\x12,\n\x08use_next\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x07origins\x18\x04 \x03(\x0b\x32!.yandex.cloud.cdn.v1.OriginParams\"<\n\x19\x43reateOriginGroupMetadata\x12\x1f\n\x0forigin_group_id\x18\x01 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"\xf0\x01\n\x18UpdateOriginGroupRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\x0forigin_group_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x30\n\ngroup_name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x08use_next\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x07origins\x18\x05 \x03(\x0b\x32!.yandex.cloud.cdn.v1.OriginParams\"<\n\x19UpdateOriginGroupMetadata\x12\x1f\n\x0forigin_group_id\x18\x01 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"\\\n\x18\x44\x65leteOriginGroupRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\x0forigin_group_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"<\n\x19\x44\x65leteOriginGroupMetadata\x12\x1f\n\x0forigin_group_id\x18\x01 \x01(\x03\x42\x06\xfa\xc7\x31\x02>02\xba\x06\n\x12OriginGroupService\x12\x84\x01\n\x03Get\x12*.yandex.cloud.cdn.v1.GetOriginGroupRequest\x1a .yandex.cloud.cdn.v1.OriginGroup\"/\x82\xd3\xe4\x93\x02)\x12\'/cdn/v1/origin_groups/{origin_group_id}\x12\x82\x01\n\x04List\x12,.yandex.cloud.cdn.v1.ListOriginGroupsRequest\x1a-.yandex.cloud.cdn.v1.ListOriginGroupsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/cdn/v1/origin_groups\x12\xa8\x01\n\x06\x43reate\x12-.yandex.cloud.cdn.v1.CreateOriginGroupRequest\x1a!.yandex.cloud.operation.Operation\"L\x82\xd3\xe4\x93\x02\x1a\"\x15/cdn/v1/origin_groups:\x01*\xb2\xd2*(\n\x19\x43reateOriginGroupMetadata\x12\x0bOriginGroup\x12\xa8\x01\n\x06Update\x12-.yandex.cloud.cdn.v1.UpdateOriginGroupRequest\x1a!.yandex.cloud.operation.Operation\"L\x82\xd3\xe4\x93\x02\x1a\x32\x15/cdn/v1/origin_groups:\x01*\xb2\xd2*(\n\x19UpdateOriginGroupMetadata\x12\x0bOriginGroup\x12\xc1\x01\n\x06\x44\x65lete\x12-.yandex.cloud.cdn.v1.DeleteOriginGroupRequest\x1a!.yandex.cloud.operation.Operation\"e\x82\xd3\xe4\x93\x02)*\'/cdn/v1/origin_groups/{origin_group_id}\xb2\xd2*2\n\x19\x44\x65leteOriginGroupMetadata\x12\x15google.protobuf.EmptyBV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2.DESCRIPTOR,yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETORIGINGROUPREQUEST = _descriptor.Descriptor(
  name='GetOriginGroupRequest',
  full_name='yandex.cloud.cdn.v1.GetOriginGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.GetOriginGroupRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_group_id', full_name='yandex.cloud.cdn.v1.GetOriginGroupRequest.origin_group_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=401,
)


_LISTORIGINGROUPSREQUEST = _descriptor.Descriptor(
  name='ListOriginGroupsRequest',
  full_name='yandex.cloud.cdn.v1.ListOriginGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.ListOriginGroupsRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.cdn.v1.ListOriginGroupsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.cdn.v1.ListOriginGroupsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=523,
)


_LISTORIGINGROUPSRESPONSE = _descriptor.Descriptor(
  name='ListOriginGroupsResponse',
  full_name='yandex.cloud.cdn.v1.ListOriginGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin_groups', full_name='yandex.cloud.cdn.v1.ListOriginGroupsResponse.origin_groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.cdn.v1.ListOriginGroupsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=525,
  serialized_end=633,
)


_CREATEORIGINGROUPREQUEST = _descriptor.Descriptor(
  name='CreateOriginGroupRequest',
  full_name='yandex.cloud.cdn.v1.CreateOriginGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.CreateOriginGroupRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.cdn.v1.CreateOriginGroupRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_next', full_name='yandex.cloud.cdn.v1.CreateOriginGroupRequest.use_next', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origins', full_name='yandex.cloud.cdn.v1.CreateOriginGroupRequest.origins', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=636,
  serialized_end=807,
)


_CREATEORIGINGROUPMETADATA = _descriptor.Descriptor(
  name='CreateOriginGroupMetadata',
  full_name='yandex.cloud.cdn.v1.CreateOriginGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin_group_id', full_name='yandex.cloud.cdn.v1.CreateOriginGroupMetadata.origin_group_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=869,
)


_UPDATEORIGINGROUPREQUEST = _descriptor.Descriptor(
  name='UpdateOriginGroupRequest',
  full_name='yandex.cloud.cdn.v1.UpdateOriginGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.UpdateOriginGroupRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_group_id', full_name='yandex.cloud.cdn.v1.UpdateOriginGroupRequest.origin_group_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_name', full_name='yandex.cloud.cdn.v1.UpdateOriginGroupRequest.group_name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_next', full_name='yandex.cloud.cdn.v1.UpdateOriginGroupRequest.use_next', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origins', full_name='yandex.cloud.cdn.v1.UpdateOriginGroupRequest.origins', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=872,
  serialized_end=1112,
)


_UPDATEORIGINGROUPMETADATA = _descriptor.Descriptor(
  name='UpdateOriginGroupMetadata',
  full_name='yandex.cloud.cdn.v1.UpdateOriginGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin_group_id', full_name='yandex.cloud.cdn.v1.UpdateOriginGroupMetadata.origin_group_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1114,
  serialized_end=1174,
)


_DELETEORIGINGROUPREQUEST = _descriptor.Descriptor(
  name='DeleteOriginGroupRequest',
  full_name='yandex.cloud.cdn.v1.DeleteOriginGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.DeleteOriginGroupRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_group_id', full_name='yandex.cloud.cdn.v1.DeleteOriginGroupRequest.origin_group_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1176,
  serialized_end=1268,
)


_DELETEORIGINGROUPMETADATA = _descriptor.Descriptor(
  name='DeleteOriginGroupMetadata',
  full_name='yandex.cloud.cdn.v1.DeleteOriginGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin_group_id', full_name='yandex.cloud.cdn.v1.DeleteOriginGroupMetadata.origin_group_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1270,
  serialized_end=1330,
)

_LISTORIGINGROUPSRESPONSE.fields_by_name['origin_groups'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__pb2._ORIGINGROUP
_CREATEORIGINGROUPREQUEST.fields_by_name['use_next'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CREATEORIGINGROUPREQUEST.fields_by_name['origins'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2._ORIGINPARAMS
_UPDATEORIGINGROUPREQUEST.fields_by_name['group_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEORIGINGROUPREQUEST.fields_by_name['use_next'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_UPDATEORIGINGROUPREQUEST.fields_by_name['origins'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2._ORIGINPARAMS
DESCRIPTOR.message_types_by_name['GetOriginGroupRequest'] = _GETORIGINGROUPREQUEST
DESCRIPTOR.message_types_by_name['ListOriginGroupsRequest'] = _LISTORIGINGROUPSREQUEST
DESCRIPTOR.message_types_by_name['ListOriginGroupsResponse'] = _LISTORIGINGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['CreateOriginGroupRequest'] = _CREATEORIGINGROUPREQUEST
DESCRIPTOR.message_types_by_name['CreateOriginGroupMetadata'] = _CREATEORIGINGROUPMETADATA
DESCRIPTOR.message_types_by_name['UpdateOriginGroupRequest'] = _UPDATEORIGINGROUPREQUEST
DESCRIPTOR.message_types_by_name['UpdateOriginGroupMetadata'] = _UPDATEORIGINGROUPMETADATA
DESCRIPTOR.message_types_by_name['DeleteOriginGroupRequest'] = _DELETEORIGINGROUPREQUEST
DESCRIPTOR.message_types_by_name['DeleteOriginGroupMetadata'] = _DELETEORIGINGROUPMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetOriginGroupRequest = _reflection.GeneratedProtocolMessageType('GetOriginGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETORIGINGROUPREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.origin_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.GetOriginGroupRequest)
  })
_sym_db.RegisterMessage(GetOriginGroupRequest)

ListOriginGroupsRequest = _reflection.GeneratedProtocolMessageType('ListOriginGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTORIGINGROUPSREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.origin_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ListOriginGroupsRequest)
  })
_sym_db.RegisterMessage(ListOriginGroupsRequest)

ListOriginGroupsResponse = _reflection.GeneratedProtocolMessageType('ListOriginGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTORIGINGROUPSRESPONSE,
  '__module__' : 'yandex.cloud.cdn.v1.origin_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ListOriginGroupsResponse)
  })
_sym_db.RegisterMessage(ListOriginGroupsResponse)

CreateOriginGroupRequest = _reflection.GeneratedProtocolMessageType('CreateOriginGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEORIGINGROUPREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.origin_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.CreateOriginGroupRequest)
  })
_sym_db.RegisterMessage(CreateOriginGroupRequest)

CreateOriginGroupMetadata = _reflection.GeneratedProtocolMessageType('CreateOriginGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEORIGINGROUPMETADATA,
  '__module__' : 'yandex.cloud.cdn.v1.origin_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.CreateOriginGroupMetadata)
  })
_sym_db.RegisterMessage(CreateOriginGroupMetadata)

UpdateOriginGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateOriginGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEORIGINGROUPREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.origin_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.UpdateOriginGroupRequest)
  })
_sym_db.RegisterMessage(UpdateOriginGroupRequest)

UpdateOriginGroupMetadata = _reflection.GeneratedProtocolMessageType('UpdateOriginGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEORIGINGROUPMETADATA,
  '__module__' : 'yandex.cloud.cdn.v1.origin_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.UpdateOriginGroupMetadata)
  })
_sym_db.RegisterMessage(UpdateOriginGroupMetadata)

DeleteOriginGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteOriginGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEORIGINGROUPREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.origin_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.DeleteOriginGroupRequest)
  })
_sym_db.RegisterMessage(DeleteOriginGroupRequest)

DeleteOriginGroupMetadata = _reflection.GeneratedProtocolMessageType('DeleteOriginGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEORIGINGROUPMETADATA,
  '__module__' : 'yandex.cloud.cdn.v1.origin_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.DeleteOriginGroupMetadata)
  })
_sym_db.RegisterMessage(DeleteOriginGroupMetadata)


DESCRIPTOR._options = None
_GETORIGINGROUPREQUEST.fields_by_name['folder_id']._options = None
_GETORIGINGROUPREQUEST.fields_by_name['origin_group_id']._options = None
_LISTORIGINGROUPSREQUEST.fields_by_name['folder_id']._options = None
_LISTORIGINGROUPSREQUEST.fields_by_name['page_size']._options = None
_LISTORIGINGROUPSREQUEST.fields_by_name['page_token']._options = None
_CREATEORIGINGROUPREQUEST.fields_by_name['folder_id']._options = None
_CREATEORIGINGROUPMETADATA.fields_by_name['origin_group_id']._options = None
_UPDATEORIGINGROUPREQUEST.fields_by_name['folder_id']._options = None
_UPDATEORIGINGROUPREQUEST.fields_by_name['origin_group_id']._options = None
_UPDATEORIGINGROUPMETADATA.fields_by_name['origin_group_id']._options = None
_DELETEORIGINGROUPREQUEST.fields_by_name['folder_id']._options = None
_DELETEORIGINGROUPREQUEST.fields_by_name['origin_group_id']._options = None
_DELETEORIGINGROUPMETADATA.fields_by_name['origin_group_id']._options = None

_ORIGINGROUPSERVICE = _descriptor.ServiceDescriptor(
  name='OriginGroupService',
  full_name='yandex.cloud.cdn.v1.OriginGroupService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1333,
  serialized_end=2159,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.cdn.v1.OriginGroupService.Get',
    index=0,
    containing_service=None,
    input_type=_GETORIGINGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__pb2._ORIGINGROUP,
    serialized_options=b'\202\323\344\223\002)\022\'/cdn/v1/origin_groups/{origin_group_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.cdn.v1.OriginGroupService.List',
    index=1,
    containing_service=None,
    input_type=_LISTORIGINGROUPSREQUEST,
    output_type=_LISTORIGINGROUPSRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/cdn/v1/origin_groups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.cdn.v1.OriginGroupService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEORIGINGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\032\"\025/cdn/v1/origin_groups:\001*\262\322*(\n\031CreateOriginGroupMetadata\022\013OriginGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.cdn.v1.OriginGroupService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEORIGINGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\0322\025/cdn/v1/origin_groups:\001*\262\322*(\n\031UpdateOriginGroupMetadata\022\013OriginGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.cdn.v1.OriginGroupService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEORIGINGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002)*\'/cdn/v1/origin_groups/{origin_group_id}\262\322*2\n\031DeleteOriginGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ORIGINGROUPSERVICE)

DESCRIPTOR.services_by_name['OriginGroupService'] = _ORIGINGROUPSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/k8s/v1/node_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.k8s.v1 import maintenance_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_maintenance__pb2
from yandex.cloud.k8s.v1 import node_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_node__pb2
from yandex.cloud.k8s.v1 import version_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_version__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/k8s/v1/node_group.proto',
  package='yandex.cloud.k8s.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8s',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$yandex/cloud/k8s/v1/node_group.proto\x12\x13yandex.cloud.k8s.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a%yandex/cloud/k8s/v1/maintenance.proto\x1a\x1eyandex/cloud/k8s/v1/node.proto\x1a!yandex/cloud/k8s/v1/version.proto\x1a\x1dyandex/cloud/validation.proto\"\xa0\x08\n\tNodeGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12:\n\x06labels\x18\x06 \x03(\x0b\x32*.yandex.cloud.k8s.v1.NodeGroup.LabelsEntry\x12\x35\n\x06status\x18\x07 \x01(\x0e\x32%.yandex.cloud.k8s.v1.NodeGroup.Status\x12\x38\n\rnode_template\x18\x08 \x01(\x0b\x32!.yandex.cloud.k8s.v1.NodeTemplate\x12\x36\n\x0cscale_policy\x18\t \x01(\x0b\x32 .yandex.cloud.k8s.v1.ScalePolicy\x12I\n\x11\x61llocation_policy\x18\n \x01(\x0b\x32..yandex.cloud.k8s.v1.NodeGroupAllocationPolicy\x12\x38\n\rdeploy_policy\x18\x12 \x01(\x0b\x32!.yandex.cloud.k8s.v1.DeployPolicy\x12\x19\n\x11instance_group_id\x18\x0b \x01(\t\x12\x14\n\x0cnode_version\x18\x0c \x01(\t\x12\x36\n\x0cversion_info\x18\r \x01(\x0b\x32 .yandex.cloud.k8s.v1.VersionInfo\x12K\n\x12maintenance_policy\x18\x0e \x01(\x0b\x32/.yandex.cloud.k8s.v1.NodeGroupMaintenancePolicy\x12\x1e\n\x16\x61llowed_unsafe_sysctls\x18\x0f \x03(\t\x12/\n\x0bnode_taints\x18\x10 \x03(\x0b\x32\x1a.yandex.cloud.k8s.v1.Taint\x12\x43\n\x0bnode_labels\x18\x11 \x03(\x0b\x32..yandex.cloud.k8s.v1.NodeGroup.NodeLabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fNodeLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x87\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0f\n\x0bRECONCILING\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x06\x12\x0c\n\x08STARTING\x10\x07\"\xb6\x02\n\x0bScalePolicy\x12\x42\n\x0b\x66ixed_scale\x18\x01 \x01(\x0b\x32+.yandex.cloud.k8s.v1.ScalePolicy.FixedScaleH\x00\x12@\n\nauto_scale\x18\x02 \x01(\x0b\x32*.yandex.cloud.k8s.v1.ScalePolicy.AutoScaleH\x00\x1a%\n\nFixedScale\x12\x17\n\x04size\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x1a\x66\n\tAutoScale\x12\x1b\n\x08min_size\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x1b\n\x08max_size\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x1f\n\x0cinitial_size\x18\x03 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100B\x12\n\nscale_type\x12\x04\xc0\xc1\x31\x01\"V\n\x19NodeGroupAllocationPolicy\x12\x39\n\tlocations\x18\x01 \x03(\x0b\x32&.yandex.cloud.k8s.v1.NodeGroupLocation\"=\n\x11NodeGroupLocation\x12\x15\n\x07zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\"\x8b\x01\n\x1aNodeGroupMaintenancePolicy\x12\x14\n\x0c\x61uto_upgrade\x18\x01 \x01(\x08\x12\x13\n\x0b\x61uto_repair\x18\x02 \x01(\x08\x12\x42\n\x12maintenance_window\x18\x03 \x01(\x0b\x32&.yandex.cloud.k8s.v1.MaintenanceWindow\"T\n\x0c\x44\x65ployPolicy\x12\"\n\x0fmax_unavailable\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12 \n\rmax_expansion\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100BV\n\x17yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8sb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_k8s_dot_v1_dot_maintenance__pb2.DESCRIPTOR,yandex_dot_cloud_dot_k8s_dot_v1_dot_node__pb2.DESCRIPTOR,yandex_dot_cloud_dot_k8s_dot_v1_dot_version__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])



_NODEGROUP_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.k8s.v1.NodeGroup.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROVISIONING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RECONCILING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STARTING', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1153,
  serialized_end=1288,
)
_sym_db.RegisterEnumDescriptor(_NODEGROUP_STATUS)


_NODEGROUP_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.k8s.v1.NodeGroup.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.k8s.v1.NodeGroup.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.k8s.v1.NodeGroup.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1054,
  serialized_end=1099,
)

_NODEGROUP_NODELABELSENTRY = _descriptor.Descriptor(
  name='NodeLabelsEntry',
  full_name='yandex.cloud.k8s.v1.NodeGroup.NodeLabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.k8s.v1.NodeGroup.NodeLabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.k8s.v1.NodeGroup.NodeLabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1101,
  serialized_end=1150,
)

_NODEGROUP = _descriptor.Descriptor(
  name='NodeGroup',
  full_name='yandex.cloud.k8s.v1.NodeGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.k8s.v1.NodeGroup.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.k8s.v1.NodeGroup.cluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.k8s.v1.NodeGroup.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.k8s.v1.NodeGroup.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.k8s.v1.NodeGroup.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.k8s.v1.NodeGroup.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.k8s.v1.NodeGroup.status', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_template', full_name='yandex.cloud.k8s.v1.NodeGroup.node_template', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale_policy', full_name='yandex.cloud.k8s.v1.NodeGroup.scale_policy', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allocation_policy', full_name='yandex.cloud.k8s.v1.NodeGroup.allocation_policy', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_policy', full_name='yandex.cloud.k8s.v1.NodeGroup.deploy_policy', index=10,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.k8s.v1.NodeGroup.instance_group_id', index=11,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_version', full_name='yandex.cloud.k8s.v1.NodeGroup.node_version', index=12,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_info', full_name='yandex.cloud.k8s.v1.NodeGroup.version_info', index=13,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_policy', full_name='yandex.cloud.k8s.v1.NodeGroup.maintenance_policy', index=14,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_unsafe_sysctls', full_name='yandex.cloud.k8s.v1.NodeGroup.allowed_unsafe_sysctls', index=15,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_taints', full_name='yandex.cloud.k8s.v1.NodeGroup.node_taints', index=16,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_labels', full_name='yandex.cloud.k8s.v1.NodeGroup.node_labels', index=17,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_NODEGROUP_LABELSENTRY, _NODEGROUP_NODELABELSENTRY, ],
  enum_types=[
    _NODEGROUP_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=1288,
)


_SCALEPOLICY_FIXEDSCALE = _descriptor.Descriptor(
  name='FixedScale',
  full_name='yandex.cloud.k8s.v1.ScalePolicy.FixedScale',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.k8s.v1.ScalePolicy.FixedScale.size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1440,
  serialized_end=1477,
)

_SCALEPOLICY_AUTOSCALE = _descriptor.Descriptor(
  name='AutoScale',
  full_name='yandex.cloud.k8s.v1.ScalePolicy.AutoScale',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_size', full_name='yandex.cloud.k8s.v1.ScalePolicy.AutoScale.min_size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_size', full_name='yandex.cloud.k8s.v1.ScalePolicy.AutoScale.max_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_size', full_name='yandex.cloud.k8s.v1.ScalePolicy.AutoScale.initial_size', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1479,
  serialized_end=1581,
)

_SCALEPOLICY = _descriptor.Descriptor(
  name='ScalePolicy',
  full_name='yandex.cloud.k8s.v1.ScalePolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fixed_scale', full_name='yandex.cloud.k8s.v1.ScalePolicy.fixed_scale', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_scale', full_name='yandex.cloud.k8s.v1.ScalePolicy.auto_scale', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCALEPOLICY_FIXEDSCALE, _SCALEPOLICY_AUTOSCALE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='scale_type', full_name='yandex.cloud.k8s.v1.ScalePolicy.scale_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=1291,
  serialized_end=1601,
)


_NODEGROUPALLOCATIONPOLICY = _descriptor.Descriptor(
  name='NodeGroupAllocationPolicy',
  full_name='yandex.cloud.k8s.v1.NodeGroupAllocationPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locations', full_name='yandex.cloud.k8s.v1.NodeGroupAllocationPolicy.locations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1603,
  serialized_end=1689,
)


_NODEGROUPLOCATION = _descriptor.Descriptor(
  name='NodeGroupLocation',
  full_name='yandex.cloud.k8s.v1.NodeGroupLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.k8s.v1.NodeGroupLocation.zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.k8s.v1.NodeGroupLocation.subnet_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1691,
  serialized_end=1752,
)


_NODEGROUPMAINTENANCEPOLICY = _descriptor.Descriptor(
  name='NodeGroupMaintenancePolicy',
  full_name='yandex.cloud.k8s.v1.NodeGroupMaintenancePolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auto_upgrade', full_name='yandex.cloud.k8s.v1.NodeGroupMaintenancePolicy.auto_upgrade', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_repair', full_name='yandex.cloud.k8s.v1.NodeGroupMaintenancePolicy.auto_repair', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_window', full_name='yandex.cloud.k8s.v1.NodeGroupMaintenancePolicy.maintenance_window', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1755,
  serialized_end=1894,
)


_DEPLOYPOLICY = _descriptor.Descriptor(
  name='DeployPolicy',
  full_name='yandex.cloud.k8s.v1.DeployPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_unavailable', full_name='yandex.cloud.k8s.v1.DeployPolicy.max_unavailable', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_expansion', full_name='yandex.cloud.k8s.v1.DeployPolicy.max_expansion', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1896,
  serialized_end=1980,
)

_NODEGROUP_LABELSENTRY.containing_type = _NODEGROUP
_NODEGROUP_NODELABELSENTRY.containing_type = _NODEGROUP
_NODEGROUP.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_NODEGROUP.fields_by_name['labels'].message_type = _NODEGROUP_LABELSENTRY
_NODEGROUP.fields_by_name['status'].enum_type = _NODEGROUP_STATUS
_NODEGROUP.fields_by_name['node_template'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_node__pb2._NODETEMPLATE
_NODEGROUP.fields_by_name['scale_policy'].message_type = _SCALEPOLICY
_NODEGROUP.fields_by_name['allocation_policy'].message_type = _NODEGROUPALLOCATIONPOLICY
_NODEGROUP.fields_by_name['deploy_policy'].message_type = _DEPLOYPOLICY
_NODEGROUP.fields_by_name['version_info'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_version__pb2._VERSIONINFO
_NODEGROUP.fields_by_name['maintenance_policy'].message_type = _NODEGROUPMAINTENANCEPOLICY
_NODEGROUP.fields_by_name['node_taints'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_node__pb2._TAINT
_NODEGROUP.fields_by_name['node_labels'].message_type = _NODEGROUP_NODELABELSENTRY
_NODEGROUP_STATUS.containing_type = _NODEGROUP
_SCALEPOLICY_FIXEDSCALE.containing_type = _SCALEPOLICY
_SCALEPOLICY_AUTOSCALE.containing_type = _SCALEPOLICY
_SCALEPOLICY.fields_by_name['fixed_scale'].message_type = _SCALEPOLICY_FIXEDSCALE
_SCALEPOLICY.fields_by_name['auto_scale'].message_type = _SCALEPOLICY_AUTOSCALE
_SCALEPOLICY.oneofs_by_name['scale_type'].fields.append(
  _SCALEPOLICY.fields_by_name['fixed_scale'])
_SCALEPOLICY.fields_by_name['fixed_scale'].containing_oneof = _SCALEPOLICY.oneofs_by_name['scale_type']
_SCALEPOLICY.oneofs_by_name['scale_type'].fields.append(
  _SCALEPOLICY.fields_by_name['auto_scale'])
_SCALEPOLICY.fields_by_name['auto_scale'].containing_oneof = _SCALEPOLICY.oneofs_by_name['scale_type']
_NODEGROUPALLOCATIONPOLICY.fields_by_name['locations'].message_type = _NODEGROUPLOCATION
_NODEGROUPMAINTENANCEPOLICY.fields_by_name['maintenance_window'].message_type = yandex_dot_cloud_dot_k8s_dot_v1_dot_maintenance__pb2._MAINTENANCEWINDOW
DESCRIPTOR.message_types_by_name['NodeGroup'] = _NODEGROUP
DESCRIPTOR.message_types_by_name['ScalePolicy'] = _SCALEPOLICY
DESCRIPTOR.message_types_by_name['NodeGroupAllocationPolicy'] = _NODEGROUPALLOCATIONPOLICY
DESCRIPTOR.message_types_by_name['NodeGroupLocation'] = _NODEGROUPLOCATION
DESCRIPTOR.message_types_by_name['NodeGroupMaintenancePolicy'] = _NODEGROUPMAINTENANCEPOLICY
DESCRIPTOR.message_types_by_name['DeployPolicy'] = _DEPLOYPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NodeGroup = _reflection.GeneratedProtocolMessageType('NodeGroup', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _NODEGROUP_LABELSENTRY,
    '__module__' : 'yandex.cloud.k8s.v1.node_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.NodeGroup.LabelsEntry)
    })
  ,

  'NodeLabelsEntry' : _reflection.GeneratedProtocolMessageType('NodeLabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _NODEGROUP_NODELABELSENTRY,
    '__module__' : 'yandex.cloud.k8s.v1.node_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.NodeGroup.NodeLabelsEntry)
    })
  ,
  'DESCRIPTOR' : _NODEGROUP,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.NodeGroup)
  })
_sym_db.RegisterMessage(NodeGroup)
_sym_db.RegisterMessage(NodeGroup.LabelsEntry)
_sym_db.RegisterMessage(NodeGroup.NodeLabelsEntry)

ScalePolicy = _reflection.GeneratedProtocolMessageType('ScalePolicy', (_message.Message,), {

  'FixedScale' : _reflection.GeneratedProtocolMessageType('FixedScale', (_message.Message,), {
    'DESCRIPTOR' : _SCALEPOLICY_FIXEDSCALE,
    '__module__' : 'yandex.cloud.k8s.v1.node_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.ScalePolicy.FixedScale)
    })
  ,

  'AutoScale' : _reflection.GeneratedProtocolMessageType('AutoScale', (_message.Message,), {
    'DESCRIPTOR' : _SCALEPOLICY_AUTOSCALE,
    '__module__' : 'yandex.cloud.k8s.v1.node_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.ScalePolicy.AutoScale)
    })
  ,
  'DESCRIPTOR' : _SCALEPOLICY,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.ScalePolicy)
  })
_sym_db.RegisterMessage(ScalePolicy)
_sym_db.RegisterMessage(ScalePolicy.FixedScale)
_sym_db.RegisterMessage(ScalePolicy.AutoScale)

NodeGroupAllocationPolicy = _reflection.GeneratedProtocolMessageType('NodeGroupAllocationPolicy', (_message.Message,), {
  'DESCRIPTOR' : _NODEGROUPALLOCATIONPOLICY,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.NodeGroupAllocationPolicy)
  })
_sym_db.RegisterMessage(NodeGroupAllocationPolicy)

NodeGroupLocation = _reflection.GeneratedProtocolMessageType('NodeGroupLocation', (_message.Message,), {
  'DESCRIPTOR' : _NODEGROUPLOCATION,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.NodeGroupLocation)
  })
_sym_db.RegisterMessage(NodeGroupLocation)

NodeGroupMaintenancePolicy = _reflection.GeneratedProtocolMessageType('NodeGroupMaintenancePolicy', (_message.Message,), {
  'DESCRIPTOR' : _NODEGROUPMAINTENANCEPOLICY,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.NodeGroupMaintenancePolicy)
  })
_sym_db.RegisterMessage(NodeGroupMaintenancePolicy)

DeployPolicy = _reflection.GeneratedProtocolMessageType('DeployPolicy', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYPOLICY,
  '__module__' : 'yandex.cloud.k8s.v1.node_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.DeployPolicy)
  })
_sym_db.RegisterMessage(DeployPolicy)


DESCRIPTOR._options = None
_NODEGROUP_LABELSENTRY._options = None
_NODEGROUP_NODELABELSENTRY._options = None
_SCALEPOLICY_FIXEDSCALE.fields_by_name['size']._options = None
_SCALEPOLICY_AUTOSCALE.fields_by_name['min_size']._options = None
_SCALEPOLICY_AUTOSCALE.fields_by_name['max_size']._options = None
_SCALEPOLICY_AUTOSCALE.fields_by_name['initial_size']._options = None
_SCALEPOLICY.oneofs_by_name['scale_type']._options = None
_NODEGROUPLOCATION.fields_by_name['zone_id']._options = None
_DEPLOYPOLICY.fields_by_name['max_unavailable']._options = None
_DEPLOYPOLICY.fields_by_name['max_expansion']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/certificatemanager/v1/certificate.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/certificatemanager/v1/certificate.proto',
  package='yandex.cloud.certificatemanager.v1',
  syntax='proto3',
  serialized_options=b'\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4yandex/cloud/certificatemanager/v1/certificate.proto\x12\"yandex.cloud.certificatemanager.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc3\x06\n\x0b\x43\x65rtificate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12K\n\x06labels\x18\x06 \x03(\x0b\x32;.yandex.cloud.certificatemanager.v1.Certificate.LabelsEntry\x12\x41\n\x04type\x18\x07 \x01(\x0e\x32\x33.yandex.cloud.certificatemanager.v1.CertificateType\x12\x0f\n\x07\x64omains\x18\x08 \x03(\t\x12\x46\n\x06status\x18\t \x01(\x0e\x32\x36.yandex.cloud.certificatemanager.v1.Certificate.Status\x12\x0e\n\x06issuer\x18\n \x01(\t\x12\x0f\n\x07subject\x18\x0b \x01(\t\x12\x0e\n\x06serial\x18\x0c \x01(\t\x12.\n\nupdated_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tissued_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tnot_after\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nnot_before\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\nchallenges\x18\x11 \x03(\x0b\x32-.yandex.cloud.certificatemanager.v1.Challenge\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"x\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0e\n\nVALIDATING\x10\x01\x12\x0b\n\x07INVALID\x10\x02\x12\n\n\x06ISSUED\x10\x03\x12\x0b\n\x07REVOKED\x10\x04\x12\x0c\n\x08RENEWING\x10\x05\x12\x12\n\x0eRENEWAL_FAILED\x10\x06\"\x8c\x05\n\tChallenge\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12?\n\x04type\x18\x02 \x01(\x0e\x32\x31.yandex.cloud.certificatemanager.v1.ChallengeType\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\x06status\x18\x05 \x01(\x0e\x32\x34.yandex.cloud.certificatemanager.v1.Challenge.Status\x12\x0f\n\x07message\x18\x06 \x01(\t\x12\r\n\x05\x65rror\x18\x07 \x01(\t\x12P\n\rdns_challenge\x18\x08 \x01(\x0b\x32\x37.yandex.cloud.certificatemanager.v1.Challenge.DnsRecordH\x00\x12P\n\x0ehttp_challenge\x18\t \x01(\x0b\x32\x36.yandex.cloud.certificatemanager.v1.Challenge.HttpFileH\x00\x1a\x36\n\tDnsRecord\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x1a(\n\x08HttpFile\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"U\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\t\n\x05VALID\x10\x03\x12\x0b\n\x07INVALID\x10\x04\x42\x0b\n\tchallenge*N\n\x0f\x43\x65rtificateType\x12 \n\x1c\x43\x45RTIFICATE_TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08IMPORTED\x10\x01\x12\x0b\n\x07MANAGED\x10\x02*B\n\rChallengeType\x12\x1e\n\x1a\x43HALLENGE_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03\x44NS\x10\x01\x12\x08\n\x04HTTP\x10\x02\x42\x83\x01\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanagerb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_CERTIFICATETYPE = _descriptor.EnumDescriptor(
  name='CertificateType',
  full_name='yandex.cloud.certificatemanager.v1.CertificateType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMPORTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANAGED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1618,
  serialized_end=1696,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATETYPE)

CertificateType = enum_type_wrapper.EnumTypeWrapper(_CERTIFICATETYPE)
_CHALLENGETYPE = _descriptor.EnumDescriptor(
  name='ChallengeType',
  full_name='yandex.cloud.certificatemanager.v1.ChallengeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CHALLENGE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DNS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1698,
  serialized_end=1764,
)
_sym_db.RegisterEnumDescriptor(_CHALLENGETYPE)

ChallengeType = enum_type_wrapper.EnumTypeWrapper(_CHALLENGETYPE)
CERTIFICATE_TYPE_UNSPECIFIED = 0
IMPORTED = 1
MANAGED = 2
CHALLENGE_TYPE_UNSPECIFIED = 0
DNS = 1
HTTP = 2


_CERTIFICATE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.certificatemanager.v1.Certificate.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VALIDATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ISSUED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REVOKED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RENEWING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RENEWAL_FAILED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=841,
  serialized_end=961,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATE_STATUS)

_CHALLENGE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.certificatemanager.v1.Challenge.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROCESSING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VALID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1518,
  serialized_end=1603,
)
_sym_db.RegisterEnumDescriptor(_CHALLENGE_STATUS)


_CERTIFICATE_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.certificatemanager.v1.Certificate.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.certificatemanager.v1.Certificate.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.certificatemanager.v1.Certificate.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=794,
  serialized_end=839,
)

_CERTIFICATE = _descriptor.Descriptor(
  name='Certificate',
  full_name='yandex.cloud.certificatemanager.v1.Certificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.certificatemanager.v1.Certificate.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.certificatemanager.v1.Certificate.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.certificatemanager.v1.Certificate.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.certificatemanager.v1.Certificate.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.certificatemanager.v1.Certificate.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.certificatemanager.v1.Certificate.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.certificatemanager.v1.Certificate.type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='domains', full_name='yandex.cloud.certificatemanager.v1.Certificate.domains', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.certificatemanager.v1.Certificate.status', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issuer', full_name='yandex.cloud.certificatemanager.v1.Certificate.issuer', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject', full_name='yandex.cloud.certificatemanager.v1.Certificate.subject', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial', full_name='yandex.cloud.certificatemanager.v1.Certificate.serial', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='yandex.cloud.certificatemanager.v1.Certificate.updated_at', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issued_at', full_name='yandex.cloud.certificatemanager.v1.Certificate.issued_at', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='not_after', full_name='yandex.cloud.certificatemanager.v1.Certificate.not_after', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='not_before', full_name='yandex.cloud.certificatemanager.v1.Certificate.not_before', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='challenges', full_name='yandex.cloud.certificatemanager.v1.Certificate.challenges', index=16,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CERTIFICATE_LABELSENTRY, ],
  enum_types=[
    _CERTIFICATE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=961,
)


_CHALLENGE_DNSRECORD = _descriptor.Descriptor(
  name='DnsRecord',
  full_name='yandex.cloud.certificatemanager.v1.Challenge.DnsRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.certificatemanager.v1.Challenge.DnsRecord.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.certificatemanager.v1.Challenge.DnsRecord.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.certificatemanager.v1.Challenge.DnsRecord.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1420,
  serialized_end=1474,
)

_CHALLENGE_HTTPFILE = _descriptor.Descriptor(
  name='HttpFile',
  full_name='yandex.cloud.certificatemanager.v1.Challenge.HttpFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='yandex.cloud.certificatemanager.v1.Challenge.HttpFile.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='yandex.cloud.certificatemanager.v1.Challenge.HttpFile.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1476,
  serialized_end=1516,
)

_CHALLENGE = _descriptor.Descriptor(
  name='Challenge',
  full_name='yandex.cloud.certificatemanager.v1.Challenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='domain', full_name='yandex.cloud.certificatemanager.v1.Challenge.domain', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.certificatemanager.v1.Challenge.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.certificatemanager.v1.Challenge.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='yandex.cloud.certificatemanager.v1.Challenge.updated_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.certificatemanager.v1.Challenge.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='yandex.cloud.certificatemanager.v1.Challenge.message', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='yandex.cloud.certificatemanager.v1.Challenge.error', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_challenge', full_name='yandex.cloud.certificatemanager.v1.Challenge.dns_challenge', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_challenge', full_name='yandex.cloud.certificatemanager.v1.Challenge.http_challenge', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHALLENGE_DNSRECORD, _CHALLENGE_HTTPFILE, ],
  enum_types=[
    _CHALLENGE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='challenge', full_name='yandex.cloud.certificatemanager.v1.Challenge.challenge',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=964,
  serialized_end=1616,
)

_CERTIFICATE_LABELSENTRY.containing_type = _CERTIFICATE
_CERTIFICATE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CERTIFICATE.fields_by_name['labels'].message_type = _CERTIFICATE_LABELSENTRY
_CERTIFICATE.fields_by_name['type'].enum_type = _CERTIFICATETYPE
_CERTIFICATE.fields_by_name['status'].enum_type = _CERTIFICATE_STATUS
_CERTIFICATE.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CERTIFICATE.fields_by_name['issued_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CERTIFICATE.fields_by_name['not_after'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CERTIFICATE.fields_by_name['not_before'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CERTIFICATE.fields_by_name['challenges'].message_type = _CHALLENGE
_CERTIFICATE_STATUS.containing_type = _CERTIFICATE
_CHALLENGE_DNSRECORD.containing_type = _CHALLENGE
_CHALLENGE_HTTPFILE.containing_type = _CHALLENGE
_CHALLENGE.fields_by_name['type'].enum_type = _CHALLENGETYPE
_CHALLENGE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CHALLENGE.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CHALLENGE.fields_by_name['status'].enum_type = _CHALLENGE_STATUS
_CHALLENGE.fields_by_name['dns_challenge'].message_type = _CHALLENGE_DNSRECORD
_CHALLENGE.fields_by_name['http_challenge'].message_type = _CHALLENGE_HTTPFILE
_CHALLENGE_STATUS.containing_type = _CHALLENGE
_CHALLENGE.oneofs_by_name['challenge'].fields.append(
  _CHALLENGE.fields_by_name['dns_challenge'])
_CHALLENGE.fields_by_name['dns_challenge'].containing_oneof = _CHALLENGE.oneofs_by_name['challenge']
_CHALLENGE.oneofs_by_name['challenge'].fields.append(
  _CHALLENGE.fields_by_name['http_challenge'])
_CHALLENGE.fields_by_name['http_challenge'].containing_oneof = _CHALLENGE.oneofs_by_name['challenge']
DESCRIPTOR.message_types_by_name['Certificate'] = _CERTIFICATE
DESCRIPTOR.message_types_by_name['Challenge'] = _CHALLENGE
DESCRIPTOR.enum_types_by_name['CertificateType'] = _CERTIFICATETYPE
DESCRIPTOR.enum_types_by_name['ChallengeType'] = _CHALLENGETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Certificate = _reflection.GeneratedProtocolMessageType('Certificate', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CERTIFICATE_LABELSENTRY,
    '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.Certificate.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CERTIFICATE,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.Certificate)
  })
_sym_db.RegisterMessage(Certificate)
_sym_db.RegisterMessage(Certificate.LabelsEntry)

Challenge = _reflection.GeneratedProtocolMessageType('Challenge', (_message.Message,), {

  'DnsRecord' : _reflection.GeneratedProtocolMessageType('DnsRecord', (_message.Message,), {
    'DESCRIPTOR' : _CHALLENGE_DNSRECORD,
    '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.Challenge.DnsRecord)
    })
  ,

  'HttpFile' : _reflection.GeneratedProtocolMessageType('HttpFile', (_message.Message,), {
    'DESCRIPTOR' : _CHALLENGE_HTTPFILE,
    '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.Challenge.HttpFile)
    })
  ,
  'DESCRIPTOR' : _CHALLENGE,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.Challenge)
  })
_sym_db.RegisterMessage(Challenge)
_sym_db.RegisterMessage(Challenge.DnsRecord)
_sym_db.RegisterMessage(Challenge.HttpFile)


DESCRIPTOR._options = None
_CERTIFICATE_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datatransfer/v1/endpoint/common.proto',
  package='yandex.cloud.datatransfer.v1.endpoint',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2yandex/cloud/datatransfer/v1/endpoint/common.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x1bgoogle/protobuf/empty.proto\" \n\x06Secret\x12\r\n\x03raw\x18\x01 \x01(\tH\x00\x42\x07\n\x05value\"\x86\x01\n\x07TLSMode\x12*\n\x08\x64isabled\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x43\n\x07\x65nabled\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.datatransfer.v1.endpoint.TLSConfigH\x00\x42\n\n\x08tls_mode\"#\n\tTLSConfig\x12\x16\n\x0e\x63\x61_certificate\x18\x01 \x01(\t*h\n\x13ObjectTransferStage\x12%\n!OBJECT_TRANSFER_STAGE_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x42\x45\x46ORE_DATA\x10\x01\x12\x0e\n\nAFTER_DATA\x10\x02\x12\t\n\x05NEVER\x10\x03\x42\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])

_OBJECTTRANSFERSTAGE = _descriptor.EnumDescriptor(
  name='ObjectTransferStage',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OBJECT_TRANSFER_STAGE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEFORE_DATA', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AFTER_DATA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEVER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=330,
  serialized_end=434,
)
_sym_db.RegisterEnumDescriptor(_OBJECTTRANSFERSTAGE)

ObjectTransferStage = enum_type_wrapper.EnumTypeWrapper(_OBJECTTRANSFERSTAGE)
OBJECT_TRANSFER_STAGE_UNSPECIFIED = 0
BEFORE_DATA = 1
AFTER_DATA = 2
NEVER = 3



_SECRET = _descriptor.Descriptor(
  name='Secret',
  full_name='yandex.cloud.datatransfer.v1.endpoint.Secret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw', full_name='yandex.cloud.datatransfer.v1.endpoint.Secret.raw', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='yandex.cloud.datatransfer.v1.endpoint.Secret.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=122,
  serialized_end=154,
)


_TLSMODE = _descriptor.Descriptor(
  name='TLSMode',
  full_name='yandex.cloud.datatransfer.v1.endpoint.TLSMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='yandex.cloud.datatransfer.v1.endpoint.TLSMode.disabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.datatransfer.v1.endpoint.TLSMode.enabled', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='tls_mode', full_name='yandex.cloud.datatransfer.v1.endpoint.TLSMode.tls_mode',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=157,
  serialized_end=291,
)


_TLSCONFIG = _descriptor.Descriptor(
  name='TLSConfig',
  full_name='yandex.cloud.datatransfer.v1.endpoint.TLSConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ca_certificate', full_name='yandex.cloud.datatransfer.v1.endpoint.TLSConfig.ca_certificate', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=293,
  serialized_end=328,
)

_SECRET.oneofs_by_name['value'].fields.append(
  _SECRET.fields_by_name['raw'])
_SECRET.fields_by_name['raw'].containing_oneof = _SECRET.oneofs_by_name['value']
_TLSMODE.fields_by_name['disabled'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TLSMODE.fields_by_name['enabled'].message_type = _TLSCONFIG
_TLSMODE.oneofs_by_name['tls_mode'].fields.append(
  _TLSMODE.fields_by_name['disabled'])
_TLSMODE.fields_by_name['disabled'].containing_oneof = _TLSMODE.oneofs_by_name['tls_mode']
_TLSMODE.oneofs_by_name['tls_mode'].fields.append(
  _TLSMODE.fields_by_name['enabled'])
_TLSMODE.fields_by_name['enabled'].containing_oneof = _TLSMODE.oneofs_by_name['tls_mode']
DESCRIPTOR.message_types_by_name['Secret'] = _SECRET
DESCRIPTOR.message_types_by_name['TLSMode'] = _TLSMODE
DESCRIPTOR.message_types_by_name['TLSConfig'] = _TLSCONFIG
DESCRIPTOR.enum_types_by_name['ObjectTransferStage'] = _OBJECTTRANSFERSTAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Secret = _reflection.GeneratedProtocolMessageType('Secret', (_message.Message,), {
  'DESCRIPTOR' : _SECRET,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.common_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.Secret)
  })
_sym_db.RegisterMessage(Secret)

TLSMode = _reflection.GeneratedProtocolMessageType('TLSMode', (_message.Message,), {
  'DESCRIPTOR' : _TLSMODE,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.common_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.TLSMode)
  })
_sym_db.RegisterMessage(TLSMode)

TLSConfig = _reflection.GeneratedProtocolMessageType('TLSConfig', (_message.Message,), {
  'DESCRIPTOR' : _TLSCONFIG,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.common_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.TLSConfig)
  })
_sym_db.RegisterMessage(TLSConfig)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
